@@ -1,8 +1,9 @@
 COMPUTE_UNAVAILABLE_FAIL_TYPE = 'compute_unavailable'
 DEPLOYMENT_TIMEOUT_FAIL_TYPE = 'deployment_timeout'
 DEPLOYMENT_ERROR_FAIL_TYPE = 'deployment_error'
+DEPLOYMENT_JOB_NOT_DEPLOYED_FAIL_TYPE = 'deployment_job_not_deployed'
 
-FAILURE_TYPES = (COMPUTE_UNAVAILABLE_FAIL_TYPE, DEPLOYMENT_TIMEOUT_FAIL_TYPE, DEPLOYMENT_ERROR_FAIL_TYPE)
+FAILURE_TYPES = (COMPUTE_UNAVAILABLE_FAIL_TYPE, DEPLOYMENT_TIMEOUT_FAIL_TYPE, DEPLOYMENT_ERROR_FAIL_TYPE, DEPLOYMENT_JOB_NOT_DEPLOYED_FAIL_TYPE)
 
 
 class DeploymentFailed(RuntimeError):
